@@ -163,7 +163,28 @@ V_WHILE,
 V_WIRE,
 V_WOR,
 V_XNORLIT,
-V_XORLIT
+V_XORLIT,
+/* Verilog 2001 additions */
+V_AUTOMATIC,
+V_CELL,
+V_CONFIG,
+V_DESIGN,
+V_ENDCONFIG,
+V_ENDGENERATE,
+V_GENERATE,
+V_GENVAR,
+V_INSTANCE,
+V_LIBLIST,
+V_LOCALPARAM,
+V_NOSHOWCANCELLED,
+V_PULSESTYLE_ONEVENT,
+V_PULSESTYLE_ONDETECT,
+V_SHOWCANCELLED,
+V_SIGNED,
+V_USE,
+V_SSHL,
+V_SSHR,
+V_POW
 };
 #endif
 
