@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2013.
+ * Copyright (c) Tony Bybell 1999-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@ enum AnalyzerBits  { AN_0, AN_X, AN_Z, AN_1, AN_H, AN_U, AN_W, AN_L, AN_DASH, AN
 #define AN_USTR_INV "1XZ0LUWH-???????"
 
 /* for writing out 4 state formats (read GHW, write LXT) */
+#define AN_STR4ST   "0xz11xz0xxxxxxxx"
 #define AN_USTR4ST  "0XZ11XZ0XXXXXXXX"
 
 /* for hex/oct conversion in baseconvert.c */
@@ -141,7 +142,7 @@ typedef struct VectorEnt
 {
 TimeType time;
 vptr next;
-unsigned char v[1];
+unsigned char v[]; /* C99 */
 } VectorEnt;
 
 #ifdef WAVE_USE_STRUCT_PACKING
@@ -394,7 +395,7 @@ typedef struct Bits
     int     nnbits;		/* number of bits in this vector */
     baptr attribs;  		/* for keeping track of combined timeshifts and inversions (and for savefile) */
     
-    nptr    nodes[1];		/* pointers to the bits (nodes)  */
+    nptr    nodes[];		/* C99 pointers to the bits (nodes)  */
   } Bits;
 
 #ifdef WAVE_USE_STRUCT_PACKING
@@ -417,7 +418,7 @@ typedef struct BitVector
     int     nbits;		/* number of bits in this vector         */
     int     numregions;		/* number of regions that follow         */
     bptr    bits;		/* pointer to Bits structs for save file */
-    vptr    vectors[1];		/* pointers to the vectors               */
+    vptr    vectors[];		/* C99 pointers to the vectors           */
   } BitVector;
 
 #ifdef WAVE_USE_STRUCT_PACKING
@@ -520,7 +521,8 @@ enum TraceEntFlagBits
   TR_ZEROFILL_B, TR_ONEFILL_B, TR_CLOSED_B, TR_GRP_BEGIN_B, 
   TR_GRP_END_B,
   TR_BINGRAY_B, TR_GRAYBIN_B,
-  TR_REAL2BITS_B, TR_TTRANSLATED_B
+  TR_REAL2BITS_B, TR_TTRANSLATED_B,
+  TR_POPCNT_B
 };
  
 #define TR_HIGHLIGHT 		(1<<TR_HIGHLIGHT_B)
@@ -563,6 +565,8 @@ enum TraceEntFlagBits
 #define TR_PTRANSLATED	(1<<TR_PTRANSLATED_B)
 #define TR_TTRANSLATED  (1<<TR_TTRANSLATED_B)
 
+#define TR_POPCNT	(1<<TR_POPCNT_B)
+
 #define TR_ANALOGMASK	(TR_ANALOG_STEP|TR_ANALOG_INTERPOLATED)
 
 Trptr GiveNextTrace(Trptr t);
