@@ -11,7 +11,30 @@
 #include <config.h>
 #include "busy.h"
 
-static void GuiDoEvent(GdkEvent *event)
+static int inside_iteration = 0;
+
+void gtk_events_pending_gtk_main_iteration(void)
+{
+inside_iteration++;
+
+while (gtk_events_pending()) gtk_main_iteration();
+
+inside_iteration--; 
+}
+
+gboolean in_main_iteration(void)
+{
+return(inside_iteration != 0);
+}
+
+
+gboolean ignore_context_swap(void)
+{
+return(GLOBALS->splash_is_loading != 0);
+}
+
+
+static void GuiDoEvent(GdkEvent *event, gpointer data)
 {
 if(!GLOBALS->busy_busy_c_1)
 	{
@@ -50,7 +73,7 @@ if(!GLOBALS->busy_busy_c_1)
 #endif
 			/* printf("event->type: %d\n", event->type); */
 			break;
-
+	
 		default:
 	            	gtk_main_do_event(event);
 			/* printf("event->type: %d\n", event->type); */
@@ -64,7 +87,7 @@ void gtkwave_main_iteration(void)
 {
 if(GLOBALS->partial_vcd)
 	{
-	while (gtk_events_pending()) gtk_main_iteration();
+	gtk_events_pending_gtk_main_iteration();
 	}
 	else
 	{
@@ -99,11 +122,11 @@ if(GLOBALS->partial_vcd)
 void init_busy(void)
 {
 GLOBALS->busycursor_busy_c_1 = gdk_cursor_new(GDK_WATCH);
-gdk_event_handler_set((GdkEventFunc)GuiDoEvent, 0, 0);
+gdk_event_handler_set((GdkEventFunc)GuiDoEvent, NULL, NULL);
 }
 
 
-void set_window_busy(GtkWidget *w)
+void set_window_busy_no_refresh(GtkWidget *w)
 {
 int i;
 
@@ -122,10 +145,13 @@ for(i=0;i<GLOBALS->num_notebook_pages;i++)
         {
         (*GLOBALS->contexts)[i]->busy_busy_c_1 = GLOBALS->busy_busy_c_1;
         }
-
-busy_window_refresh();
 }
 
+void set_window_busy(GtkWidget *w)
+{
+set_window_busy_no_refresh(w);
+busy_window_refresh();
+}
 
 void set_window_idle(GtkWidget *w)
 {
@@ -156,7 +182,7 @@ void busy_window_refresh(void)
 {
 if(GLOBALS->busy_busy_c_1)
 	{
-	while (gtk_events_pending()) gtk_main_iteration();
+	gtk_events_pending_gtk_main_iteration();
 	}
 }
 
