@@ -21,11 +21,15 @@
 #define WAVE_BUSY_ITER (1000)
 
 void init_busy(void); 
+void set_window_busy_no_refresh(GtkWidget *w);
 void set_window_busy(GtkWidget *w);
 void set_window_idle(GtkWidget *w);
 void busy_window_refresh(void);
 
 void gtkwave_main_iteration(void);
+void gtk_events_pending_gtk_main_iteration(void);
+gboolean in_main_iteration(void);
+gboolean ignore_context_swap(void);
 
 #endif
 
