@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2009-2013.
+ * Copyright (c) Tony Bybell 2009-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -350,6 +350,11 @@ for(;;)
 						}
 						else
 						{
+						if(!strcmp(vtyp_nam, "stream"))
+							{
+							GLOBALS->extload_idcodes[i] = 0; /* kill being able to read stream variables [transactions] for now */
+							}
+
 						vt = V_WIRE;
 						}
 					}
@@ -480,7 +485,7 @@ for(;;)
 				ttype = TREE_UNKNOWN;
 				}
 
-	                allocate_and_decorate_module_tree_node(ttype, cname, ctype,  strlen(cname), strlen(ctype));
+	                allocate_and_decorate_module_tree_node(ttype, cname, ctype,  strlen(cname), strlen(ctype), 0, 0);
 			}
 		}
 	else
@@ -781,13 +786,6 @@ if(GLOBALS->extload_ffr_ctx)
 		success_count++;
 		}
 
-	attempt_count++;
-	max_idcode = fsdbReaderGetMaxVarIdcode(GLOBALS->extload_ffr_ctx);
-	if(max_idcode)
-		{
-		success_count++;
-		}
-	
 	attempt_count++;
 	gs = fsdbReaderGetStatistics(GLOBALS->extload_ffr_ctx);
 	if(gs)
@@ -797,6 +795,18 @@ if(GLOBALS->extload_ffr_ctx)
 		success_count++;
 		}
 
+	attempt_count++;
+	max_idcode = fsdbReaderGetMaxVarIdcode(GLOBALS->extload_ffr_ctx);
+	if(max_idcode)
+		{
+		success_count++;
+		}
+	else
+		{
+		max_idcode = GLOBALS->numfacs; /* for 1.x format files */
+		success_count++;
+		}
+
 	if(attempt_count != success_count)
 		{
 		fprintf(stderr, EXTLOAD"Could not initialize '%s' properly.\n", fname);
@@ -1256,6 +1266,9 @@ int len, i;
 struct fac *f;
 int txidx, txidx_in_trace;
 nptr nold = np;
+#ifdef WAVE_FSDB_READER_IS_PRESENT
+void *trans_info;
+#endif
 
 if(!(f=np->mv.mvlfac)) return;	/* already imported */
 
@@ -1285,6 +1298,11 @@ fprintf(stderr, EXTLOAD"Import: %s\n", np->nname);
 len = np->mv.mvlfac->len;
 
 #ifdef WAVE_FSDB_READER_IS_PRESENT
+if(0)
+{
+/* process transactions here */
+}
+else /* "normal" VC data */
 {
 void *hdl;
 
