@@ -23,5 +23,9 @@
 TimeType 	extload_main(char *fname, char *skip_start, char *skip_end);
 void 		import_extload_trace(nptr np);
 
+/* FsdbReader adds */
+void 		fsdb_import_masked(void);
+void 		fsdb_set_fac_process_mask(nptr np);
+
 #endif
 
