@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2013.
+ * Copyright (c) Tony Bybell 2013-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,11 @@
 #include "ffrAPI.h"
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
+#endif
+
+#define FSDBR_FXT2U64(xt) (((uint64_t)(xt).hltag.H << 32) | ((uint64_t)(xt).hltag.L))
 
 #ifndef FALSE
 #define FALSE   0
@@ -40,6 +44,7 @@ static bool_T __MyTreeCB(fsdbTreeCBType cb_type, void *client_data, void *tree_c
 extern "C" void *fsdbReaderOpenFile(char *nam)
 {
 fsdbFileType ft;
+uint_T blk_idx = 0;
 
 if(!ffrObject::ffrIsFSDB(nam))
 	{
@@ -68,6 +73,8 @@ if((ft != FSDB_FT_VERILOG) && (ft != FSDB_FT_VERILOG_VHDL) && (ft != FSDB_FT_VHD
 	return(NULL);
 	}
 
+fsdb_obj->ffrReadDataTypeDefByBlkIdx(blk_idx); /* necessary if FSDB file has transaction data ... we don't process this but it prevents possible crashes */
+
 return((void *)fsdb_obj);
 }
 
@@ -256,17 +263,59 @@ switch (vc_trvs_hdl->ffrGetBytesPerBit())
 		    		case FSDB_BT_VCD_1:
 		        		buffer[i] = '1';
 		        		break;
-
-		    		case FSDB_BT_VCD_X:
-		        		buffer[i] = 'x';
-		        		break;
 	
 		    		case FSDB_BT_VCD_Z:
 		        		buffer[i] = 'z';
 		        		break;
 	
+		    		case FSDB_BT_VCD_X:
 		    		default:
-		        		buffer[i] = 'u';
+		        		buffer[i] = 'x';
+					break;
+		    		}
+	        	}
+	        buffer[i] = 0;
+		break;
+
+	case FSDB_BYTES_PER_BIT_2B:
+	        for (i = 0; i < vc_trvs_hdl->ffrGetBitSize(); i++) 
+			{
+		    	switch(vc_ptr[i * 2]) 
+				{
+				case FSDB_BT_EVCD_D:
+				case FSDB_BT_EVCD_d:
+				case FSDB_BT_EVCD_L:
+				case FSDB_BT_EVCD_l:
+				case FSDB_BT_EVCD_0:
+		        		buffer[i] = '0';
+		        		break;
+	
+				case FSDB_BT_EVCD_U:
+				case FSDB_BT_EVCD_u:
+				case FSDB_BT_EVCD_H:
+				case FSDB_BT_EVCD_h:
+				case FSDB_BT_EVCD_1:
+		        		buffer[i] = '1';
+		        		break;
+	
+				case FSDB_BT_EVCD_Z:
+				case FSDB_BT_EVCD_T:
+				case FSDB_BT_EVCD_F:
+				case FSDB_BT_EVCD_f:
+		        		buffer[i] = 'z';
+		        		break;
+	
+				case FSDB_BT_EVCD_N:
+				case FSDB_BT_EVCD_X:
+				case FSDB_BT_EVCD_QSTN:
+				case FSDB_BT_EVCD_A:
+				case FSDB_BT_EVCD_a:
+				case FSDB_BT_EVCD_B:
+				case FSDB_BT_EVCD_b:
+				case FSDB_BT_EVCD_C:
+				case FSDB_BT_EVCD_c:
+		    		default:
+		        		buffer[i] = 'x';
 					break;
 		    		}
 	        	}
@@ -290,7 +339,7 @@ switch (vc_trvs_hdl->ffrGetBytesPerBit())
 		break;
 	
 	case FSDB_BYTES_PER_BIT_8B:
-		sprintf((char *)buffer, "%lg", *((double*)vc_ptr));
+		sprintf((char *)buffer, "%.16g", *((double*)vc_ptr));
 		break;
 
 	default:
@@ -313,7 +362,7 @@ fsdbRC rc = fsdb_obj->ffrExtractScaleUnit(su, digit, unit);
 
 if(rc == FSDB_RC_SUCCESS)
 	{
-	*mult = ((int)digit);
+	*mult = digit ? ((int)digit) : 1; /* in case digit is zero */
 	*scale = unit[0];
 	}
 
@@ -359,6 +408,8 @@ switch (cb_type)
 	{
 	case FSDB_TREE_CBT_VAR:		gs->varCount++;
 					break;
+
+	case FSDB_TREE_CBT_STRUCT_BEGIN:
 	case FSDB_TREE_CBT_SCOPE:	gs->scopeCount++;
 					break;
 
@@ -608,6 +659,11 @@ switch (var->type)
 		typelen = 7;
 		break;
 
+    	case FSDB_VT_VCD_PORT:
+		type = (str_T) "vcd_port";
+		typelen = 8;
+		break;
+
     	case FSDB_VT_VHDL_SIGNAL:
     	case FSDB_VT_VHDL_VARIABLE:
     	case FSDB_VT_VHDL_CONSTANT:
@@ -646,6 +702,11 @@ switch (var->type)
 			}
 		break;
 
+	case FSDB_VT_STREAM: /* these hold transactions: not yet supported */
+		type = (str_T) "stream";
+		typelen = 6;
+		break;
+
     	default:
 		type = (str_T) "vcd_wire";
 		typelen = 8;
@@ -784,6 +845,53 @@ return(TRUE);
 }
 
 
+/*
+ * $dumpoff/$dumpon support
+ */
+extern "C" unsigned int fsdbReaderGetDumpOffRange(void *ctx, struct fsdbReaderBlackoutChain_t **r)   
+{
+ffrObject *fsdb_obj = (ffrObject *)ctx;
+ 
+if(fsdb_obj->ffrHasDumpOffRange())
+        {
+        uint_T count;
+        fsdbDumpOffRange *fdr = NULL;
+
+        if(FSDB_RC_SUCCESS == fsdb_obj->ffrGetDumpOffRange(count, fdr))
+                {
+                uint_T i;
+                *r = (struct fsdbReaderBlackoutChain_t *)calloc(count * 2, sizeof(struct fsdbReaderBlackoutChain_t));
+
+                for(i=0;i<count;i++)
+                        {
+                        (*r)[i].tim = FSDBR_FXT2U64(fdr[i*2  ].begin); (*r)[i*2  ].active = 0;
+                        (*r)[i].tim = FSDBR_FXT2U64(fdr[i*2+1].begin); (*r)[i*2+1].active = 1;
+                        }
+
+                return(count*2);
+                }
+        }
+
+if(*r) { *r = NULL; }
+return(0);
+}
+
+
+/*
+ * Transactions are currently not processed and are skipped
+ */
+extern "C" int fsdbReaderGetTransInfo(void *ctx, int idx, void **trans_info)
+{
+ffrObject *fsdb_obj = (ffrObject *)ctx;
+ffrTransInfo *info = NULL;
+
+fsdbRC rc = fsdb_obj->ffrGetTransInfo((fsdbTransId)idx, info);
+*trans_info = info;
+
+return(rc != FSDB_RC_FAILURE);
+}
+
+
 #else
 
 static void dummy_compilation_unit(void)
