@@ -193,7 +193,10 @@ while((h = fstReaderIterateHier(xc)))
 				default:			ttype = TREE_UNKNOWN; break;
 				}
 
-			allocate_and_decorate_module_tree_node(ttype, h->u.scope.name, h->u.scope.component,  h->u.scope.name_length, h->u.scope.component_length);
+			allocate_and_decorate_module_tree_node(ttype, h->u.scope.name, h->u.scope.component, h->u.scope.name_length, h->u.scope.component_length, 
+				GLOBALS->stem_valid ? GLOBALS->stem_struct_base_siz : 0, 
+				GLOBALS->istem_valid ? GLOBALS->istem_struct_base_siz : 0);
+			GLOBALS->stem_valid = GLOBALS->istem_valid = 0;
                         break;
                 case FST_HT_UPSCOPE:
 			GLOBALS->mod_tree_parent = fstReaderGetCurrentScopeUserInfo(xc);
@@ -360,6 +363,83 @@ while((h = fstReaderIterateHier(xc)))
 					GLOBALS->supplemental_datatypes_encountered = 1;
 					GLOBALS->supplemental_vartypes_encountered |= ((svt != FST_SVT_NONE) && (svt != FST_SVT_VHDL_SIGNAL));
 					}
+				else
+				if(h->u.attr.subtype == FST_MT_SOURCEISTEM)
+					{
+					uint32_t istem_path_number = (uint32_t)h->u.attr.arg_from_name;
+					uint32_t istem_line_number = (uint32_t)h->u.attr.arg;
+
+					if(istem_path_number <= GLOBALS->stem_path_string_table_siz) /* prevent overflows from malformed writers */
+						{
+						GLOBALS->istem_valid = 1;
+						if(!GLOBALS->istem_struct_base)
+							{
+							GLOBALS->istem_struct_base_siz_alloc = 1;
+							GLOBALS->istem_struct_base_siz = 0;
+							GLOBALS->istem_struct_base = malloc_2(GLOBALS->istem_struct_base_siz_alloc * sizeof(struct stem_struct_t));
+							}
+
+						if(GLOBALS->istem_struct_base_siz == GLOBALS->istem_struct_base_siz_alloc)
+							{
+							GLOBALS->istem_struct_base_siz_alloc *= 2;
+							GLOBALS->istem_struct_base = realloc_2(GLOBALS->istem_struct_base, GLOBALS->istem_struct_base_siz_alloc * sizeof(struct stem_struct_t));
+							}
+
+						GLOBALS->istem_struct_base[GLOBALS->istem_struct_base_siz].stem_idx = istem_path_number - 1;
+						GLOBALS->istem_struct_base[GLOBALS->istem_struct_base_siz].stem_line_number = istem_line_number;
+						GLOBALS->istem_struct_base_siz++;
+						}
+					}
+				else
+				if(h->u.attr.subtype == FST_MT_SOURCESTEM)
+					{
+					uint32_t stem_path_number = (uint32_t)h->u.attr.arg_from_name;
+					uint32_t stem_line_number = (uint32_t)h->u.attr.arg;
+
+					if(stem_path_number <= GLOBALS->stem_path_string_table_siz) /* prevent overflows from malformed writers */
+						{
+						GLOBALS->stem_valid = 1;
+						if(!GLOBALS->stem_struct_base)
+							{
+							GLOBALS->stem_struct_base_siz_alloc = 1;
+							GLOBALS->stem_struct_base_siz = 0;
+							GLOBALS->stem_struct_base = malloc_2(GLOBALS->stem_struct_base_siz_alloc * sizeof(struct stem_struct_t));
+							}
+
+						if(GLOBALS->stem_struct_base_siz == GLOBALS->stem_struct_base_siz_alloc)
+							{
+							GLOBALS->stem_struct_base_siz_alloc *= 2;
+							GLOBALS->stem_struct_base = realloc_2(GLOBALS->stem_struct_base, GLOBALS->stem_struct_base_siz_alloc * sizeof(struct stem_struct_t));
+							}
+
+						GLOBALS->stem_struct_base[GLOBALS->stem_struct_base_siz].stem_idx = stem_path_number - 1;
+						GLOBALS->stem_struct_base[GLOBALS->stem_struct_base_siz].stem_line_number = stem_line_number;
+						GLOBALS->stem_struct_base_siz++;
+						}
+					}
+				else
+				if(h->u.attr.subtype == FST_MT_PATHNAME)
+					{
+					if(h->u.attr.name && ((GLOBALS->stem_path_string_table_siz+1) == h->u.attr.arg))
+						{
+						/* == check against h->u.attr.arg is a sanity check against the writer */
+						if(!GLOBALS->stem_path_string_table)
+							{
+							GLOBALS->stem_path_string_table_alloc = 1;
+							GLOBALS->stem_path_string_table_siz = 0;
+							GLOBALS->stem_path_string_table = malloc_2(GLOBALS->stem_path_string_table_alloc * sizeof(char *));
+							}
+
+						if(GLOBALS->stem_path_string_table_siz == GLOBALS->stem_path_string_table_alloc)
+							{
+							GLOBALS->stem_path_string_table_alloc *= 2;
+							GLOBALS->stem_path_string_table = realloc_2(GLOBALS->stem_path_string_table, GLOBALS->stem_path_string_table_alloc * sizeof(char *));
+							}
+						
+						GLOBALS->stem_path_string_table[GLOBALS->stem_path_string_table_siz] = strdup_2(h->u.attr.name);
+						GLOBALS->stem_path_string_table_siz++;
+						}
+					}
 				}
 			break;
 
@@ -379,7 +459,7 @@ return(NULL);
 
 static void fst_append_graft_chain(int len, char *nam, int which, struct tree *par)
 {
-struct tree *t = talloc_2(sizeof(struct tree) + len);
+struct tree *t = talloc_2(sizeof(struct tree) + len + 1);
 
 memcpy(t->name, nam, len+1);
 t->t_which = which;
@@ -678,6 +758,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		else /* convert any variable length records into strings */
 		{
 		nvt = ND_GEN_STRING;
+		nvd = ND_DIR_IMPLICIT;
 		GLOBALS->mvlfacs_fst_c_3[i].flags = VZT_RD_SYM_F_STRING;
 		GLOBALS->mvlfacs_fst_c_3[i].len = 2;
 		}
@@ -935,6 +1016,33 @@ if(GLOBALS->subvar_jrb_count) /* generate lookup table for typenames explicitly
 		}
 	}
 
+if(GLOBALS->istem_struct_base)
+	{
+	if(GLOBALS->istem_struct_base_siz != GLOBALS->istem_struct_base_siz_alloc)
+		{
+		GLOBALS->istem_struct_base_siz_alloc = GLOBALS->istem_struct_base_siz;
+		GLOBALS->istem_struct_base = realloc_2(GLOBALS->istem_struct_base, GLOBALS->istem_struct_base_siz_alloc * sizeof(struct stem_struct_t));
+		}
+	}
+
+if(GLOBALS->stem_struct_base)
+	{
+	if(GLOBALS->stem_struct_base_siz != GLOBALS->stem_struct_base_siz_alloc)
+		{
+		GLOBALS->stem_struct_base_siz_alloc = GLOBALS->stem_struct_base_siz;
+		GLOBALS->stem_struct_base = realloc_2(GLOBALS->stem_struct_base, GLOBALS->stem_struct_base_siz_alloc * sizeof(struct stem_struct_t));
+		}
+	}
+
+if(GLOBALS->stem_path_string_table)
+	{
+	if(GLOBALS->stem_path_string_table_siz != GLOBALS->stem_path_string_table_alloc)
+		{
+		GLOBALS->stem_path_string_table_alloc = GLOBALS->stem_path_string_table_siz;
+		GLOBALS->stem_path_string_table = realloc_2(GLOBALS->stem_path_string_table, GLOBALS->stem_path_string_table_alloc * sizeof(char *));
+		}
+	}
+
 decorated_module_cleanup(); /* ...also now in gtk2_treesearch.c */
 freeze_facility_pack();
 iter_through_comp_name_table();
