@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2012.
+ * Copyright (c) Kermin Elliott Fleming 2007-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -104,8 +104,8 @@ NULL, /* ae2_time_xlate */
  * analyzer.c
  */
 TR_RJUSTIFY, /* default_flags 5 */
-{0, 0, 0, 0, 0, 0, 0}, /* tims 6 */
-{0, 0, NULL, NULL, NULL, NULL, 0, NULL, NULL}, /* traces 9 */
+{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0, 0.0}, /* tims 6 */
+{0, 0, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0}, /* traces 9 */
 0, /* hier_max_level 8 */
 0, /* hier_max_level_shadow */
 0, /* timestart_from_savefile */
@@ -322,6 +322,19 @@ NULL, /* subvar_jrb */
 NULL, /* subvar_pnt */
 0, /* fst_filetype */
 0, /* subvar_jrb_count_locked */
+0, /* stem_file_idx */
+0, /* stem_line_number */
+NULL, /* stem_path_string_table */
+NULL, /* stem_struct_base */
+NULL, /* istem_struct_base */
+0, /* stem_path_string_table_siz */
+0, /* stem_path_string_table_alloc */
+0, /* stem_struct_base_siz */
+0, /* stem_struct_base_siz_alloc */
+0, /* istem_struct_base_siz */
+0, /* istem_struct_base_siz_alloc */
+0, /* stem_valid  */
+0, /* istem_valid */
 
 
 /*
@@ -356,7 +369,7 @@ NULL, /* gtk_context_bridge_ptr */
 0, /* text_help_c_1 111 */
 0, /* vscrollbar_help_c_1 112 */
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
-{0}, /* iter_help_c_1 113 */
+{NULL, NULL, 0, 0, 0, 0, 0, 0, NULL, NULL, 0, 0, 0, NULL}, /* iter_help_c_1 113 */
 0, /* bold_tag_help_c_1 114 */
 #endif
 0, /* window_help_c_2 115 */
@@ -403,7 +416,7 @@ NULL, /* logfiles */
 NULL, /* fontname_logfile 133 */
 NULL, /* font_logfile_c_1 134 */
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
-{0}, /* iter_logfile_c_2 135 */
+{NULL, NULL, 0, 0, 0, 0, 0, 0, NULL, NULL, 0, 0, 0, NULL}, /* iter_logfile_c_2 135 */
 NULL, /* bold_tag_logfile_c_2 136 */
 NULL, /* mono_tag_logfile_c_1 137 */
 NULL, /* size_tag_logfile_c_1 138 */
@@ -613,6 +626,7 @@ NULL, /* filesel_tim_writesave */
 0, /* lock_menu_c_2 252 */
 NULL, /* buf_menu_c_1 253 128 */
 NULL, /* signal_popup_menu */
+NULL, /* sst_signal_popup_menu */
 
 /*
  * mouseover.c
@@ -742,6 +756,7 @@ NULL, /* clist_ptranslate_c_2 316 */
  */
 0, /* rc_line_no 318 */
 1, /* possibly_use_rc_defaults 319 */
+NULL, /* editor_string */
 
 
 /*
@@ -860,6 +875,8 @@ NULL, /* signalarea_event_box */
 0, /* cached_mouseover_x */
 0, /* cached_mouseover_y */
 0, /* mouseover_counter */
+0, /* button2_debounce_flag */
+
 
 /*
  * simplereq.c
@@ -891,7 +908,7 @@ NULL, /* gt_splash_c_1 393 */
 NULL, /* text_status_c_2 398 */
 NULL, /* vscrollbar_status_c_2 399 */
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
-{0}, /* iter_status_c_3 400 */
+{NULL, NULL, 0, 0, 0, 0, 0, 0, NULL, NULL, 0, 0, 0, NULL}, /* iter_status_c_3 400 */
 NULL, /* bold_tag_status_c_3 401 */
 #endif
 
@@ -1047,6 +1064,7 @@ NULL, /* entry_a_treesearch_gtk2_c_2 455 */
 NULL, /* entrybox_text_local_treesearch_gtk2_c_3 456 */
 NULL, /* cleanup_e_treesearch_gtk2_c_3 457 */
 NULL, /* sig_root_treesearch_gtk2_c_1 458 */
+NULL, /* sst_sig_root_treesearch_gtk2_c_1 */
 NULL, /* filter_str_treesearch_gtk2_c_1 459 */
 ND_DIR_UNSPECIFIED, /* filter_typ_treesearch_gtk2_c_1 */
 0, /* filter_matlen_treesearch_gtk2_c_1 */
@@ -1063,7 +1081,7 @@ NULL, /* tree_treesearch_gtk2_c_1 466 */
 0, /* bundle_direction_treesearch_gtk2_c_3 467 */
 NULL, /* cleanup_treesearch_gtk2_c_8 468 */
 0, /* pre_import_treesearch_gtk2_c_1 469 */
-{0,0,0,NULL,NULL,NULL,0}, /* tcache_treesearch_gtk2_c_2 470 */
+{0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0}, /* tcache_treesearch_gtk2_c_2 470 */
 0, /* dnd_tgt_on_signalarea_treesearch_gtk2_c_1 471 */
 0, /* dnd_tgt_on_wavearea_treesearch_gtk2_c_1 */
 NULL, /* dnd_sigview */
@@ -1585,12 +1603,10 @@ void reload_into_new_context_2(void)
 
  /* Save state to file */
  save_tmpfilename = tmpnam_2(NULL, &fd_dummy);
- statefile = fopen(save_tmpfilename,"wb");
+ statefile = save_tmpfilename ? fopen(save_tmpfilename,"wb") : NULL;
  if(statefile == NULL) {
-   fprintf(stderr, "Failed to reload file.\n");
-#if !defined _MSC_VER && !defined __MINGW32__
-   free_2(save_tmpfilename);
-#endif
+   fprintf(stderr, "Failed to create temp file required for file reload.\n");
+   if(save_tmpfilename) { perror("Why"); free_2(save_tmpfilename); }
    gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,"reload failed",WAVE_TCLCB_ERROR_FLAGS);
    return;
  }
@@ -1599,9 +1615,7 @@ void reload_into_new_context_2(void)
  fclose(statefile);
 
  reload_tmpfilename = strdup(save_tmpfilename);
-#if !defined _MSC_VER && !defined __MINGW32__
  free_2(save_tmpfilename);
-#endif
  
  /* save off size of tree frame if active */
 #if WAVE_USE_GTK2
@@ -1882,6 +1896,7 @@ void reload_into_new_context_2(void)
  new_globals->logfiles = GLOBALS->logfiles; /* this value is a ** chameleon!  malloc'd region is outside debug.c control! */
 
  strcpy2_into_new_context(new_globals, &new_globals->argvlist, &GLOBALS->argvlist);
+ strcpy2_into_new_context(new_globals, &new_globals->editor_name, &GLOBALS->editor_name);
  strcpy2_into_new_context(new_globals, &new_globals->fontname_logfile, &GLOBALS->fontname_logfile);
  strcpy2_into_new_context(new_globals, &new_globals->fontname_signals, &GLOBALS->fontname_signals); 
  strcpy2_into_new_context(new_globals, &new_globals->fontname_waves, &GLOBALS->fontname_waves);
@@ -1922,6 +1937,7 @@ void reload_into_new_context_2(void)
  strcpy2_into_new_context(new_globals, &new_globals->filesel_writesave, &GLOBALS->filesel_writesave);
  new_globals->save_success_menu_c_1 = GLOBALS->save_success_menu_c_1; 
  new_globals->signal_popup_menu = GLOBALS->signal_popup_menu;
+ new_globals->sst_signal_popup_menu = GLOBALS->sst_signal_popup_menu;
 
  strcpy2_into_new_context(new_globals, &new_globals->filesel_vcd_writesave, &GLOBALS->filesel_vcd_writesave);
  strcpy2_into_new_context(new_globals, &new_globals->filesel_lxt_writesave, &GLOBALS->filesel_lxt_writesave);
@@ -2169,6 +2185,7 @@ void reload_into_new_context_2(void)
  /* Free the old globals struct, memsetting it to zero in the hope of forcing crashes. */
  memset(GLOBALS, 0, sizeof(struct Global));
  free(GLOBALS);
+ GLOBALS = NULL; /* valgrind fix */
 
  /* Set the GLOBALS pointer to the newly allocated struct. */
  set_GLOBALS(new_globals);
@@ -2676,6 +2693,7 @@ if(gp)
 	/* Free the old globals struct, memsetting it to zero in the hope of forcing crashes. */
 	memset(GLOBALS, 0, sizeof(struct Global));
 	free(GLOBALS);
+	GLOBALS = NULL; /* valgrind fix */
 
 	set_GLOBALS(g_curr);
 	}
