@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2011.
+ * Copyright (c) Kermin Elliott Fleming 2007-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -321,6 +321,19 @@ unsigned int subvar_jrb_count;
 char **subvar_pnt;
 unsigned char fst_filetype;
 unsigned subvar_jrb_count_locked : 1;
+uint32_t stem_file_idx;
+uint32_t stem_line_number;
+char **stem_path_string_table;
+struct stem_struct_t *stem_struct_base;
+struct stem_struct_t *istem_struct_base;
+uint32_t stem_path_string_table_siz;
+uint32_t stem_path_string_table_alloc;  
+uint32_t stem_struct_base_siz;
+uint32_t stem_struct_base_siz_alloc;
+uint32_t istem_struct_base_siz;
+uint32_t istem_struct_base_siz_alloc;
+unsigned stem_valid : 1;
+unsigned istem_valid : 1;
 
 
 /*
@@ -609,6 +622,7 @@ int lock_menu_c_1; /* from menu.c 268 */
 int lock_menu_c_2; /* from menu.c 269 */
 char *buf_menu_c_1; /* from menu.c 270 */
 GtkWidget *signal_popup_menu; /* from menu.c */
+GtkWidget *sst_signal_popup_menu; /* from menu.c */
 
 
 /*
@@ -739,6 +753,7 @@ GtkWidget *clist_ptranslate_c_2; /* from ptranslate.c 334 */
  */
 int rc_line_no; /* from rc.c 336 */
 int possibly_use_rc_defaults; /* from rc.c 337 */
+char *editor_name; /* from rc.c */
 
 
 /*
@@ -857,6 +872,7 @@ gint keypress_handler_id; /* from signalwindow.c */
 gint cached_mouseover_x; /* from signalwindow.c */
 gint cached_mouseover_y; /* from signalwindow.c */
 gint mouseover_counter; /* from signalwindow.c */
+unsigned button2_debounce_flag : 1;
 
 
 /*
@@ -1030,6 +1046,7 @@ GtkWidget *entry_a_treesearch_gtk2_c_2; /* from treesearch_gtk2.c 485 */
 char *entrybox_text_local_treesearch_gtk2_c_3; /* from treesearch_gtk2.c 486 */
 void (*cleanup_e_treesearch_gtk2_c_3)(void); /* from treesearch_gtk2.c 487 */
 struct tree *sig_root_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 488 */
+struct tree *sst_sig_root_treesearch_gtk2_c_1; /* from treesearch_gtk2.c */
 char *filter_str_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 489 */
 int filter_typ_treesearch_gtk2_c_1;
 int filter_matlen_treesearch_gtk2_c_1;
