@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-9 Tony Bybell.
+ * Copyright (c) 2003-2014 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -44,25 +44,18 @@ extern char *fv_output_hier(FILE *fv, char *name);
 /*
  * generate a vcd identifier for a given facindx
  */
-static char *vcdid(int value)
+static char *vcdid(unsigned int value)
 {
 static char buf[16];
 char *pnt = buf;
-int i, vmod;
 
 value++;
-for(i=0;;i++)
+/* zero is illegal for a value...it is assumed they start at one */
+while (value)
         {
-        if((vmod = (value % 94)))
-                {
-                *(pnt++) = (char)(vmod + 32);
-                }   
-                else
-                {
-                *(pnt++) = '~'; value -= 94;
-                }
-        value = value / 94;  
-        if(!value) { break; }
+        value--;
+        *(pnt++) = (char)('!' + value % 94);
+        value = value / 94;
         }
 
 *pnt = 0;   
