@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001 Tony Bybell.
+ * Copyright (c) 2001-2014 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,9 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
 #include <wavealloca.h>
 
 struct memchunk
@@ -41,8 +44,8 @@ size_t size;
  * types...
  */
 #define G_HAVE_GINT64
-#define gint64 long long
-#define guint64 unsigned long long
+#define gint64 int64_t
+#define guint64 uint64_t
 
 #ifdef G_HAVE_GINT64
 typedef gint64          TimeType; 
@@ -52,7 +55,11 @@ typedef guint64         UTimeType;
 #define LLDescriptor(x) x##LL
 #define ULLDescriptor(x) x##ULL
 #ifndef __MINGW32__
+#if __WORDSIZE == 64
+#define TTFormat "%ld"
+#else
 #define TTFormat "%lld"
+#endif
 #else
 #define TTFormat "%I64d"
 #endif
