@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2013 Tony Bybell.
+ * Copyright (c) 2009-2014 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -42,7 +42,13 @@
 #endif
 #endif
 
-#if defined(VCD2FST_EXTLOAD_CONV) || defined(VCD2FST_EXT2LOAD_CONV)
+#ifdef EXT3LOAD_SUFFIX
+#ifdef EXT3CONV_PATH
+#define VCD2FST_EXT3LOAD_CONV
+#endif
+#endif
+
+#if defined(VCD2FST_EXTLOAD_CONV) || defined(VCD2FST_EXT2LOAD_CONV) || defined(VCD2FST_EXT3LOAD_CONV)
 #define VCD2FST_EXTLOADERS_CONV
 #endif
 
@@ -334,7 +340,31 @@ if(comp_name_jrb)
 /*** ^^^ extload component type name determination ^^^ ***/
 /*********************************************************/
 
-size_t getline_replace(char **wbuf, char **buf, size_t *len, FILE *f)
+static uint64_t atoi_2(const unsigned char *s)
+{
+uint64_t res = 0;
+unsigned char ch;
+
+ch = *s - '0';
+while(*s && (ch > 9))
+        {
+        s++;
+	ch = *s - '0';
+        }
+
+while(ch < 10)
+        {
+        s++;
+        res *= 10;
+        res += ch;
+	ch = *s - '0';
+        }
+
+return(res);
+}
+
+
+static inline int getline_replace(char **wbuf, char **buf, size_t *len, FILE *f)
 {
 char *fgets_rc;
 
@@ -362,7 +392,7 @@ while(*(buf)[0]==' ') { (*buf)++; } /* verilator leading spaces fix */
 
 if((!(*buf)[0])||(!fgets_rc))
 	{
-	return(-1);
+	return(0);
 	}
 	else
 	{
@@ -388,16 +418,19 @@ for(i=0;i<len;i++)
 return(val);
 }  
 
-int pack_type = 0;  /* set to 1 for fastlz */
+int pack_type = FST_WR_PT_LZ4;  /* set to fstWriterPackType */
+int compression_explicitly_set = 0;
 int repack_all = 0; /* 0 is normal, 1 does the repack (via fstapi) at end */
 int parallel_mode = 0; /* 0 is is single threaded, 1 is multi-threaded */
 
 
+#ifdef VCD2FST_EXTLOADERS_CONV
 static int suffix_check(const char *s, const char *sfx)
 {
 int sfxlen = strlen(sfx);
 return((strlen(s)>=sfxlen)&&(!strcasecmp(s+strlen(s)-sfxlen,sfx)));
 }
+#endif
 
 
 int fst_main(char *vname, char *fstname)
@@ -407,7 +440,7 @@ char *buf = NULL, *wbuf = NULL;
 size_t glen = 0;
 void *ctx;
 int line = 0;
-size_t ss;
+int ss;
 fstHandle returnedhandle;
 JRB node;
 uint64_t prev_tim = 0;
@@ -421,6 +454,7 @@ int is_popen = 0;
 int is_extload = 0;
 void *xc = NULL;
 #endif
+int port_encountered = 0;
 
 bin_fixbuff = malloc(bin_fixbuff_len);
 
@@ -453,6 +487,15 @@ if(!strcmp("-", vname))
 			is_popen = 1;
 			}
 			else
+#endif
+#ifdef VCD2FST_EXT3LOAD_CONV
+		if(suffix_check(vname, "."EXT3LOAD_SUFFIX))
+			{
+			sprintf(bin_fixbuff, EXT3CONV_PATH" %s", vname);
+			f = popen(bin_fixbuff, "r");
+			is_popen = 1;
+			}
+			else
 #endif
 			{
 			f = fopen(vname, "rb");
@@ -462,7 +505,7 @@ if(!strcmp("-", vname))
 
 if(!f)
 	{
-	printf("could not open '%s', exiting.\n", vname);
+	printf("Could not open '%s', exiting.\n", vname);
 	free(bin_fixbuff); bin_fixbuff = NULL;
 	exit(255);
 	}
@@ -471,7 +514,7 @@ ctx = fstWriterCreate(fstname, 1);
 
 if(!ctx)
 	{
-	printf("could not open '%s', exiting.\n", fstname);
+	printf("Could not open '%s', exiting.\n", fstname);
 	free(bin_fixbuff); bin_fixbuff = NULL;
 	exit(255);
 	}
@@ -493,7 +536,7 @@ while(!feof(f))
 	char *buf1;
 
 	ss = getline_replace(&wbuf, &buf, &glen, f);
-	if(ss == -1)
+	if(!ss)
 		{
 		break;
 		}
@@ -560,6 +603,7 @@ while(!feof(f))
 				if(!strcmp(st, "port"))
 					{
 					vartype = FST_VT_VCD_PORT;
+					port_encountered = 1;
 					}
 				break;
 
@@ -688,7 +732,29 @@ while(!feof(f))
 		len = atoi(st);
 		switch(vartype)
 			{
-			case FST_VT_VCD_PORT: len = (len * 3) + 2; break;
+			case FST_VT_VCD_PORT: 
+				if(*st == '[') /* VCS extension, so reparse */
+					{
+					int p_hi = atoi(st+1);
+					int p_lo = p_hi;
+					char *p_colon = strchr(st+1, ':');
+					if(p_colon)
+						{
+						p_lo = atoi(p_colon+1);
+						}
+
+					if(p_hi > p_lo)
+						{
+						len = p_hi - p_lo + 1;
+						}
+						else
+						{
+						len = p_lo - p_hi + 1;
+						}
+					}
+
+				len = (len * 3) + 2; 
+				break;
 			case FST_VT_GEN_STRING: len = 0; break;
 			case FST_VT_VCD_EVENT: len = (len != 0) ? len : 1;  break;
 			default: 
@@ -976,28 +1042,32 @@ while(!feof(f))
 			dealloc_scope();
 			}
 #endif
+		if(port_encountered && (!compression_explicitly_set) && (pack_type == FST_WR_PT_LZ4)) /* EVCD data compresses far better with fastlz, so use if not directed explicitly */
+			{
+			fstWriterSetPackType(ctx, (pack_type = FST_WR_PT_FASTLZ));
+			}
 		break;
 		}
 	else
 	if(!strncmp(buf1, "timezero", 8))
 		{
 		char *pnt;
-		uint64_t tzero = 0;
+		int64_t tzero = 0;
 
 		if((pnt = strstr(buf, "$end")))
 			{
 			*pnt = 0;
-			sscanf(buf+10, "%"SCNu64, &tzero);
+			sscanf(buf+10, "%"SCNd64, &tzero);
 			}
 		else
                         {
                         ss = getline_replace(&wbuf, &buf, &glen, f);
-                        if(ss == -1)
+                        if(!ss)
                                 {
                                 break;
                                 }
                         line++;             
-			sscanf(buf, "%"SCNu64, &tzero);
+			sscanf(buf, "%"SCNd64, &tzero);
                         }
 
 		fstWriterSetTimezero(ctx, tzero);
@@ -1019,7 +1089,7 @@ while(!feof(f))
 		if(!num)
 			{
 			ss = getline_replace(&wbuf, &buf, &glen, f);
-			if(ss == -1)
+			if(!ss)
 				{
 				break;
 				}
@@ -1105,7 +1175,7 @@ while(!feof(f))
 		if(!found)		
 			{
 			ss = getline_replace(&wbuf, &buf, &glen, f);
-			if(ss == -1)
+			if(!ss)
 				{
 				break;
 				}
@@ -1142,7 +1212,7 @@ while(!feof(f))
 			else
 			{
 			ss = getline_replace(&wbuf, &buf, &glen, f);
-			if(ss == -1)
+			if(!ss)
 				{
 				break;
 				}
@@ -1194,7 +1264,7 @@ if((!hash_kill) && (vcd_ids))
 	hash_kill = 1; /* scan-build */
 	}
 
-while(!feof(f))
+for(;;) /* was while(!feof(f)) */
 	{
 	unsigned int hash;
 	uint64_t tim;
@@ -1202,7 +1272,7 @@ while(!feof(f))
 	double doub;
 
 	ss = getline_replace(&wbuf, &buf, &glen, f);
-	if(ss == -1)
+	if(!ss)
 		{
 		break;
 		}
@@ -1243,7 +1313,24 @@ while(!feof(f))
 			break;
 
 		case 'b':
-			sp = strchr(buf, ' ');
+			{ /* this block replaces the single statement sp = strchr(buf, ' ');        */
+			  /* as the odds are the VCD ID will be small compared to the vector length */
+			char *sp_scan = nl;
+			sp = NULL;
+
+			/* if(buf != sp_scan) [can't happen or switch() wouldn't get here] */
+				{
+				while(buf != --sp_scan)
+					{
+					if(*sp_scan == ' ')
+						{
+						sp = sp_scan;
+						break;
+						}
+					}
+				}
+			}
+
 			if(!sp) break;
 			*sp = 0;
 			hash = vcdid_hash(sp+1, nl - (sp+1));
@@ -1347,7 +1434,7 @@ while(!feof(f))
 
 			for(;;)
 				{
-				if((*src == '\n') || (*src == '\r')) break;
+				if(!*src) break;
 				if(isspace((int)(unsigned char)*src))
 					{
 					if(pchar != ' ') { *(pnt++) = pchar = ' '; }
@@ -1365,7 +1452,8 @@ while(!feof(f))
 			sp = strchr(sp+1, ' ');
 			if(!sp) break;
 			*sp = 0;
-			hash = vcdid_hash(sp+1, nl - (sp+1));
+
+			hash = vcdid_hash(sp+1, strlen(sp+1)); /* nl is no longer good here */
 			if(!hash_kill)
 				{
 				fstWriterEmitValueChange(ctx, hash, bin_fixbuff);
@@ -1431,7 +1519,7 @@ while(!feof(f))
 			break;
 
 		case '#':
-			sscanf(buf+1, "%"SCNu64, &tim);
+			tim = atoi_2((unsigned char *)(buf+1));
 			if((tim >= prev_tim)||(!prev_tim))
 				{
 				prev_tim = tim;
@@ -1501,60 +1589,51 @@ return(0);
 void print_help(char *nam)
 {
 #ifdef VCD2FST_EXTLOADERS_CONV
-#if defined(VCD2FST_EXTLOAD_CONV) && defined(VCD2FST_EXT2LOAD_CONV)
 
-int slen = strlen(EXTLOAD_SUFFIX) + 1 + strlen(EXT2LOAD_SUFFIX);
-char *ucase_ext = calloc(1, slen+1);
+int slen;
+char *ucase_ext = calloc(1, 1024);
 int i;
 
-sprintf(ucase_ext, "%s/%s", EXTLOAD_SUFFIX, EXT2LOAD_SUFFIX);
+ucase_ext[0] = 0;
+
+#if defined(VCD2FST_EXTLOAD_CONV)
+strcat(ucase_ext, "/");
+strcat(ucase_ext, EXTLOAD_SUFFIX);
+#endif
+
+#if defined(VCD2FST_EXT2LOAD_CONV)
+strcat(ucase_ext, "/");
+strcat(ucase_ext, EXT2LOAD_SUFFIX);
+#endif
+
+#if defined(VCD2FST_EXT3LOAD_CONV)
+strcat(ucase_ext, "/");
+strcat(ucase_ext, EXT3LOAD_SUFFIX);
+#endif
+
+slen = strlen(ucase_ext);
 
 for(i=0;i<slen;i++)
 	{
 	ucase_ext[i] = toupper(ucase_ext[i]);
 	}
 
-#else
-#ifdef VCD2FST_EXTLOAD_CONV
-int slen = strlen(EXTLOAD_SUFFIX);
-char *ucase_ext = calloc(1, slen+1);
-int i;
-
-for(i=0;i<slen;i++)
-	{
-	ucase_ext[i] = toupper(EXTLOAD_SUFFIX[i]);
-	}
 #endif
-#ifdef VCD2FST_EXT2LOAD_CONV
-int slen = strlen(EXT2LOAD_SUFFIX);
-char *ucase_ext = calloc(1, slen+1);
-int i;
-
-for(i=0;i<slen;i++)
-	{
-	ucase_ext[i] = toupper(EXT2LOAD_SUFFIX[i]);
-	}
-#endif
-#endif
-
-#endif
-
-
-
-
 
 
 #ifdef __linux__ 
 printf(
 "Usage: %s [OPTION]... [VCDFILE] [FSTFILE]\n\n"
 #ifdef VCD2FST_EXTLOADERS_CONV
-"  -v, --vcdname=FILE         specify VCD/%s input filename\n"
+"  -v, --vcdname=FILE         specify VCD%s input filename\n"
 #else
 "  -v, --vcdname=FILE         specify VCD input filename\n"
 #endif
 "  -f, --fstname=FILE         specify FST output filename\n"
+"  -4, --fourpack             use lz4 algorithm for speed (default)\n"
 "  -F, --fastpack             use fastlz algorithm for speed\n"
-"  -c, --compress             compress entire file on close\n"
+"  -Z, --zlibpack             use zlib algorithm for size\n"
+"  -c, --compress             zlib compress entire file on close\n"
 "  -p, --parallel             enable parallel mode\n"
 "  -h, --help                 display this help then exit\n\n"
 
@@ -1569,13 +1648,15 @@ printf(
 printf(
 "Usage: %s [OPTION]... [VCDFILE] [FSTFILE]\n\n"
 #ifdef VCD2FST_EXTLOADERS_CONV
-"  -v FILE                    specify VCD/%s input filename\n"
+"  -v FILE                    specify VCD%s input filename\n"
 #else
 "  -v FILE                    specify VCD input filename\n"
 #endif
 "  -f FILE                    specify FST output filename\n"
+"  -4                         use lz4 algorithm for speed (default)\n"
 "  -F                         use fastlz algorithm for speed\n"
-"  -c                         compress entire file on close\n"
+"  -Z                         use zlib algorithm for size\n"
+"  -c                         zlib compress entire file on close\n"
 "  -p                         enable parallel mode\n"
 "  -h                         display this help then exit\n\n"
 
@@ -1614,15 +1695,17 @@ while (1)
 		{"vcdname", 1, 0, 'v'},
 		{"fstname", 1, 0, 'f'},
 		{"fastpack", 0, 0, 'F'},
+		{"fourpack", 0, 0, '4'},
+		{"zlibpack", 0, 0, 'Z'},
 		{"compress", 0, 0, 'c'},
 		{"parallel", 0, 0, 'p'},
                 {"help", 0, 0, 'h'},
                 {0, 0, 0, 0}  
                 };
                 
-        c = getopt_long (argc, argv, "v:f:Fcph", long_options, &option_index);
+        c = getopt_long (argc, argv, "v:f:ZF4cph", long_options, &option_index);
 #else
-        c = getopt      (argc, argv, "v:f:Fcph");
+        c = getopt      (argc, argv, "v:f:ZF4cph");
 #endif
                         
         if (c == -1) break;     /* no more args */
@@ -1641,8 +1724,19 @@ while (1)
                         strcpy(lxname, optarg);
 			break;
 
+		case 'Z':
+			compression_explicitly_set = 1;
+			pack_type = FST_WR_PT_ZLIB;
+			break;
+
 		case 'F':
-			pack_type = 1;
+			compression_explicitly_set = 1;
+			pack_type = FST_WR_PT_FASTLZ;
+			break;
+
+		case '4':
+			compression_explicitly_set = 1;
+			pack_type = FST_WR_PT_LZ4;
 			break;
 
 		case 'c':
