@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2010 Tony Bybell.
+ * Copyright (c) 2001-2014 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -47,7 +47,7 @@ int numfacs=0;
 int deadcnt=0;
 
 int opt_depth = 4;
-unsigned long long opt_break_size = 0;
+uint64_t opt_break_size = 0;
 int opt_partial_mode = -1;
 int opt_checkpoint_disable = 0;
 int opt_maxgranule = 8;
@@ -245,6 +245,8 @@ return(strcmp(v1->id, v2->id));
  */
 static void alias_vs_normal_symadd(struct vcdsymbol *v, struct vcdsymbol *root_v)
 {
+if(!v) return; /* scan-build : should never happen */
+
 if(!root_v) 
 	{
 	if((v->vartype==V_INTEGER)||(v->vartype==V_REAL))
@@ -1959,7 +1961,7 @@ while (1)
 			break;
 
 		case 'b':
-			sscanf(optarg, "%llu", &opt_break_size);
+			sscanf(optarg, "%"SCNu64, &opt_break_size);
 			errno = 0;
 			break;
 
