@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2012 Tony Bybell.
+ * Copyright (c) 2003-2014 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -36,12 +36,6 @@
 #include <fcntl.h>
 #endif
 
-#if defined(USE_INLINE_ASM)
-#if defined(__i386__) || defined(__x86_64__)
-#define USE_X86_INLINE_ASM
-#endif
-#endif
-
 /****************************************************************************/
 
 static int is_big_endian(void)
@@ -132,43 +126,6 @@ if(lt->pthreads)
  
 #else
 
-/*
- * reconstruct 8/16/24/32 bits out of the vzt's representation
- * of a big-endian integer.  x86 specific version...
- */
-
-#ifdef USE_X86_INLINE_ASM
-
-#define vzt_rd_get_byte(mm,offset)		((unsigned int)(*((unsigned char *)(mm)+(offset))))
-
-_VZT_RD_INLINE static unsigned int vzt_rd_get_16(void *mm, int offset)
-{
-unsigned short x = *((unsigned short *)((unsigned char *)mm+offset));
-
-#if defined(__x86_64__)
-    __asm("xchgb %b0,%h0" : "=Q" (x) : "0" (x));
-#else
-    __asm("xchgb %b0,%h0" : "=q" (x) : "0" (x));
-#endif
-
-    return (unsigned int) x;
-}
-
-_VZT_RD_INLINE static unsigned int vzt_rd_get_32(void *mm, int offset)		/* note that bswap is really 486+ */
-{
-unsigned int x = *((unsigned int *)((unsigned char *)mm+offset));
-
- __asm("bswap   %0":
-      "=r" (x) :
-      "0" (x));
-
-  return x;
-}
-
-#define vzt_rd_get_64(mm,offset)      ((((vztint64_t)vzt_rd_get_32((mm),(offset)))<<32)|((vztint64_t)vzt_rd_get_32((mm),(offset)+4)))
-
-#else
-
 /*
  * reconstruct 8/16/24/32 bits out of the vzt's representation
  * of a big-endian integer.  this should work on all architectures.
@@ -201,7 +158,6 @@ return(
 );
 }
 
-#endif
 #endif
 
 static unsigned int vzt_rd_get_32r(void *mm, int offset)
@@ -861,7 +817,7 @@ struct vzt_ncycle_autosort *autofacs= calloc(lt->numrealfacs, sizeof(struct vzt_
 vzt_rd_block_vch_decode(lt, b);
 vzt_rd_pthread_mutex_lock(lt, &b->mutex);
 
-autosort = calloc(b->num_time_ticks, sizeof(struct vzt_ncycle_autosort));
+autosort = calloc(b->num_time_ticks, sizeof(struct vzt_ncycle_autosort *));
 for(i=0;i<b->num_time_ticks;i++) autosort[i]=NULL;
 deadlist=NULL;
 
@@ -2102,6 +2058,8 @@ if((!lt)||(lt->vectorize)||(lt->numfacs<2))
 			}
 		}
 
+	free(pbuff); /* scan-build */
+
 	for(i=lt->numrealfacs;i<lt->numfacs;i++)
 		{
 		if(lt->flags[i] & VZT_RD_SYM_F_ALIAS)	/* not necessary, only for sanity */
