@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2012.
+ * Copyright (c) Tony Bybell 1999-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,7 @@
 
 /*
 #define WAVE_CRASH_ON_GTK_WARNING
- */
+*/
 
 #include "wave_locale.h"
 
@@ -84,7 +84,6 @@
 
 char *gtkwave_argv0_cached = NULL;
 
-
 static void switch_page(GtkNotebook     *notebook,
 			GtkNotebookPage *page,
 			guint            page_num,
@@ -370,7 +369,7 @@ if(dfile)
 		}
 #endif
 	}
-fileselbox_old("GTKWave: Select a dumpfile...",&GLOBALS->ftext_main_main_c_1,GTK_SIGNAL_FUNC(wave_get_filename_cleanup), GTK_SIGNAL_FUNC(wave_get_filename_cleanup), NULL);
+fileselbox_old("GTKWave: Select a dumpfile...",&GLOBALS->ftext_main_main_c_1,GTK_SIGNAL_FUNC(wave_get_filename_cleanup), GTK_SIGNAL_FUNC(wave_get_filename_cleanup), NULL, 0);
 gtk_main();
 
 return(GLOBALS->ftext_main_main_c_1);
@@ -471,7 +470,7 @@ if(!GLOBALS)
 	mainwindow_already_built = 0;
 	tcl_interpreter_needs_making = 1;
 
-	GLOBALS->logfiles = calloc(1, sizeof(void **)); /* calloc is deliberate! */
+	GLOBALS->logfiles = calloc(1, sizeof(void *)); /* calloc is deliberate! */
 	}
 	else
 	{
@@ -650,6 +649,7 @@ if(!GLOBALS)
 	GLOBALS->make_vcd_save_file = old_g->make_vcd_save_file;
 	GLOBALS->strace_repeat_count = old_g->strace_repeat_count;
 
+	strcpy2_into_new_context(GLOBALS, &GLOBALS->editor_name, &old_g->editor_name);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_logfile, &old_g->fontname_logfile);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_signals, &old_g->fontname_signals); 
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_waves, &old_g->fontname_waves);
@@ -1145,6 +1145,28 @@ if(is_wish && is_vcd)
 	exit(255);
 	}
 
+
+#if defined(EXTLOAD_SUFFIX) && defined(EXTCONV_PATH)
+#if !defined(FSDB_IS_PRESENT) || !defined(FSDB_NSYS_IS_PRESENT)
+if(GLOBALS->loaded_file_name && suffix_check(GLOBALS->loaded_file_name, "."EXTLOAD_SUFFIX))
+	{
+	opt_vcd = 1;
+	}
+#endif
+#endif
+#if defined(EXT2LOAD_SUFFIX) && defined(EXT2CONV_PATH)
+if(GLOBALS->loaded_file_name && suffix_check(GLOBALS->loaded_file_name, "."EXT2LOAD_SUFFIX))
+	{
+	opt_vcd = 1;
+	}
+#endif
+#if defined(EXT3LOAD_SUFFIX) && defined(EXT3CONV_PATH)
+if(GLOBALS->loaded_file_name && suffix_check(GLOBALS->loaded_file_name, "."EXT3LOAD_SUFFIX))
+	{
+	opt_vcd = 1;
+	}
+#endif
+
 /* attempt to load a dump+save file if only a savefile is specified at the command line */
 if((GLOBALS->loaded_file_name) && (!wname) &&
 	(suffix_check(GLOBALS->loaded_file_name, ".gtkw") || suffix_check(GLOBALS->loaded_file_name, ".sav")))
@@ -2247,7 +2269,7 @@ if(GLOBALS->treeopen_chain_head)
 		{
 		if(GLOBALS->ctree_main)
 			{
-			force_open_tree_node(t->str, 0);
+			force_open_tree_node(t->str, 0, NULL);
 			}
 
 		t2 = t->next;
@@ -2273,12 +2295,12 @@ if(!GLOBALS->notebook)
 	{
 	GLOBALS->num_notebook_pages = 1;
 	GLOBALS->this_context_page = 0;
-	GLOBALS->contexts = calloc(1, sizeof(struct Globals ***)); /* calloc is deliberate! */
-	*GLOBALS->contexts = calloc(1, sizeof(struct Globals **)); /* calloc is deliberate! */
+	GLOBALS->contexts = calloc(1, sizeof(struct Global **)); /* calloc is deliberate! */ /* scan-build */
+	*GLOBALS->contexts = calloc(1, sizeof(struct Global *)); /* calloc is deliberate! */ /* scan-build */
 	(*GLOBALS->contexts)[0] = GLOBALS;
 
-	GLOBALS->dead_context = calloc(1, sizeof(struct Globals ***)); /* calloc is deliberate! */
-	*GLOBALS->dead_context = calloc(1, sizeof(struct Globals **)); /* calloc is deliberate! */
+	GLOBALS->dead_context = calloc(1, sizeof(struct Global **)); /* calloc is deliberate! */ /* scan-build */
+	*GLOBALS->dead_context = calloc(1, sizeof(struct Global *)); /* calloc is deliberate! */ /* scan-build */
 	*(GLOBALS->dead_context)[0] = NULL;
 
 	GLOBALS->notebook = gtk_notebook_new();
@@ -2296,7 +2318,7 @@ if(!GLOBALS->notebook)
 	GLOBALS->this_context_page = GLOBALS->num_notebook_pages;
 	GLOBALS->num_notebook_pages++;
 	GLOBALS->num_notebook_pages_cumulative++; /* this never decreases, acts as an incrementing flipper id for side tabs */
-	*GLOBALS->contexts = realloc(*GLOBALS->contexts, GLOBALS->num_notebook_pages * sizeof(struct Globals *)); /* realloc is deliberate! */
+	*GLOBALS->contexts = realloc(*GLOBALS->contexts, GLOBALS->num_notebook_pages * sizeof(struct Global *)); /* realloc is deliberate! */ /* scan-build */
 	(*GLOBALS->contexts)[GLOBALS->this_context_page] = GLOBALS;
 
 	for(ix=0;ix<GLOBALS->num_notebook_pages;ix++)
