@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2013.
+ * Copyright (c) Tony Bybell 1999-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 #include "main.h"
 
 void do_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
+void do_sst_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
 void get_main_menu (GtkWidget *, GtkWidget **menubar);
 void menu_set_sensitive(void);
 int file_quit_cmd_callback (GtkWidget *widget, gpointer data);
@@ -159,6 +160,8 @@ WV_MENU_RFILLOFF,
 WV_MENU_B2G,
 WV_MENU_G2B,
 WV_MENU_GBNONE,
+WV_MENU_POPON,
+WV_MENU_POPOFF,
 WV_MENU_CLRFMT0,
 WV_MENU_CLRFMT1,
 WV_MENU_CLRFMT2,
@@ -203,6 +206,10 @@ WV_MENU_SSR,
 WV_MENU_SSH,
 WV_MENU_SST,
 WV_MENU_SEP7,
+#if !defined __MINGW32__ && !defined _MSC_VER
+WV_MENU_OPENHS,
+WV_MENU_OPENIHS,
+#endif
 WV_MENU_OPENH,
 WV_MENU_SEP7D,
 WV_MENU_ACOL,
