@@ -180,10 +180,11 @@ if(GLOBALS->traces.first)
                                 t->p_filter = which;
 				if(!which)
 					{
-					t->flags &= (~(TR_FTRANSLATED|TR_PTRANSLATED));
+					t->flags &= (~(TR_FTRANSLATED|TR_PTRANSLATED|TR_ANALOGMASK));
 					}
 					else
 					{
+					t->flags &= (~(TR_ANALOGMASK));
 					t->flags |= TR_PTRANSLATED;
 					}
                                 found++;
