@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2011.
+ * Copyright (c) Tony Bybell 1999-2013.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,64 +39,64 @@ static char *stype[WAVE_STYPE_COUNT]=
 
 static struct item_mark_string item_mark_start_strings[]=
 	{
-	   { "Start of Time"  },
-	   { "Named Marker A" },
-	   { "Named Marker B" },
-	   { "Named Marker C" },
-	   { "Named Marker D" },
-	   { "Named Marker E" },
-	   { "Named Marker F" },
-	   { "Named Marker G" },
-	   { "Named Marker H" },
-	   { "Named Marker I" },
-	   { "Named Marker J" },
-	   { "Named Marker K" },
-	   { "Named Marker L" },
-	   { "Named Marker M" },
-	   { "Named Marker N" },
-	   { "Named Marker O" },
-	   { "Named Marker P" },
-	   { "Named Marker Q" },
-	   { "Named Marker R" },
-	   { "Named Marker S" },
-	   { "Named Marker T" },
-	   { "Named Marker U" },
-	   { "Named Marker V" },
-	   { "Named Marker W" },
-	   { "Named Marker X" },
-	   { "Named Marker Y" },
-	   { "Named Marker Z" }
+	   { "Start of Time",  0 },
+	   { "Named Marker A", 0 },
+	   { "Named Marker B", 0 },
+	   { "Named Marker C", 0 },
+	   { "Named Marker D", 0 },
+	   { "Named Marker E", 0 },
+	   { "Named Marker F", 0 },
+	   { "Named Marker G", 0 },
+	   { "Named Marker H", 0 },
+	   { "Named Marker I", 0 },
+	   { "Named Marker J", 0 },
+	   { "Named Marker K", 0 },
+	   { "Named Marker L", 0 },
+	   { "Named Marker M", 0 },
+	   { "Named Marker N", 0 },
+	   { "Named Marker O", 0 },
+	   { "Named Marker P", 0 },
+	   { "Named Marker Q", 0 },
+	   { "Named Marker R", 0 },
+	   { "Named Marker S", 0 },
+	   { "Named Marker T", 0 },
+	   { "Named Marker U", 0 },
+	   { "Named Marker V", 0 },
+	   { "Named Marker W", 0 },
+	   { "Named Marker X", 0 },
+	   { "Named Marker Y", 0 },
+	   { "Named Marker Z", 0 }
 	};
 
 static struct item_mark_string item_mark_end_strings[]=
 	{
-	   { "End of Time"    },
-	   { "Named Marker A" },
-	   { "Named Marker B" },
-	   { "Named Marker C" },
-	   { "Named Marker D" },
-	   { "Named Marker E" },
-	   { "Named Marker F" },
-	   { "Named Marker G" },
-	   { "Named Marker H" },
-	   { "Named Marker I" },
-	   { "Named Marker J" },
-	   { "Named Marker K" },
-	   { "Named Marker L" },
-	   { "Named Marker M" },
-	   { "Named Marker N" },
-	   { "Named Marker O" },
-	   { "Named Marker P" },
-	   { "Named Marker Q" },
-	   { "Named Marker R" },
-	   { "Named Marker S" },
-	   { "Named Marker T" },
-	   { "Named Marker U" },
-	   { "Named Marker V" },
-	   { "Named Marker W" },
-	   { "Named Marker X" },
-	   { "Named Marker Y" },
-	   { "Named Marker Z" }
+	   { "End of Time",    0 },
+	   { "Named Marker A", 0 },
+	   { "Named Marker B", 0 },
+	   { "Named Marker C", 0 },
+	   { "Named Marker D", 0 },
+	   { "Named Marker E", 0 },
+	   { "Named Marker F", 0 },
+	   { "Named Marker G", 0 },
+	   { "Named Marker H", 0 },
+	   { "Named Marker I", 0 },
+	   { "Named Marker J", 0 },
+	   { "Named Marker K", 0 },
+	   { "Named Marker L", 0 },
+	   { "Named Marker M", 0 },
+	   { "Named Marker N", 0 },
+	   { "Named Marker O", 0 },
+	   { "Named Marker P", 0 },
+	   { "Named Marker Q", 0 },
+	   { "Named Marker R", 0 },
+	   { "Named Marker S", 0 },
+	   { "Named Marker T", 0 },
+	   { "Named Marker U", 0 },
+	   { "Named Marker V", 0 },
+	   { "Named Marker W", 0 },
+	   { "Named Marker X", 0 },
+	   { "Named Marker Y", 0 },
+	   { "Named Marker Z", 0 }
 	};
 
 
