@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2012.
+ * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -2654,11 +2654,11 @@ if(objc > 1)
 		{
 		char *s = Tcl_GetString(objv[i]);
 		int slen = strlen(s);
-		struct wave_script_args *w = wave_alloca(sizeof(struct wave_script_args) + slen);
+		struct wave_script_args *w = wave_alloca(sizeof(struct wave_script_args) + slen + 1);
 			/*  alloca used in case we context switch and get our allocator ripped out from under us -- the call stack won't go away */
 		if(slen)
 			{
-			strcpy(w->payload, s);
+			strcpy(w->payload, s); /* scan-build complains but it thinks payload[1] is the actual memory allocated */
 			}
 		w->curr = NULL; /* yes, curr is only ever used for the 1st struct, but there is no sense creating head/follower structs for this */
 		w->next = NULL;
@@ -2681,7 +2681,7 @@ if(objc > 1)
 
 	if(!GLOBALS->wave_script_args) /* create a dummy list in order to keep requesters from popping up in file.c, etc. */
 		{
-		GLOBALS->wave_script_args = wave_alloca(sizeof(struct wave_script_args));
+		GLOBALS->wave_script_args = wave_alloca(sizeof(struct wave_script_args) + 1);
 		GLOBALS->wave_script_args->curr = NULL;
 		GLOBALS->wave_script_args->next = NULL;
 		GLOBALS->wave_script_args->payload[0] = 0;
