@@ -19,8 +19,8 @@ int SST_open_node(char *name);
 
 llist_p *llist_new(llist_u v, ll_elem_type type, int arg); 
 llist_p *llist_append(llist_p *head, llist_p *elem, llist_p **tail); 
-llist_p *llist_remove_last(llist_p *head, llist_p **tail, ll_elem_type type, void *f() ); 
-void llist_free(llist_p *head, ll_elem_type type, void *f()); 
+llist_p *llist_remove_last(llist_p *head, llist_p **tail, ll_elem_type type, void *f(void *) ); 
+void llist_free(llist_p *head, ll_elem_type type, void *f(void *)); 
 
 llist_p *signal_change_list(char *sig_name, int dir, TimeType start_time,
                        TimeType end_time, int max_elements); 
