@@ -140,7 +140,7 @@ return(1);
 /*
  * decorated module add
  */
-void allocate_and_decorate_module_tree_node(unsigned char ttype, const char *scopename, const char *compname, uint32_t scopename_len, uint32_t compname_len)
+void allocate_and_decorate_module_tree_node(unsigned char ttype, const char *scopename, const char *compname, uint32_t scopename_len, uint32_t compname_len, uint32_t t_stem, uint32_t t_istem)
 {
 struct tree *t;
 int mtyp = WAVE_T_WHICH_UNDEFINED_COMPNAME;
@@ -176,7 +176,7 @@ if(GLOBALS->treeroot)
 				return;
 				}
 
-			t = talloc_2(sizeof(struct tree) + scopename_len);
+			t = talloc_2(sizeof(struct tree) + scopename_len + 1);
 			*PPValue = t;
 			goto t_allocated;
 			}
@@ -219,20 +219,22 @@ if(GLOBALS->treeroot)
 
 				strcpy(str+len, scopename);
 				PPValue = JudySLIns(&GLOBALS->sym_tree, (uint8_t *)str, PJE0);
-				t = talloc_2(sizeof(struct tree) + scopename_len);
+				t = talloc_2(sizeof(struct tree) + scopename_len + 1);
 				*PPValue = t;
 				goto t_allocated;
 				}
 			}
 #endif
 
-		t = talloc_2(sizeof(struct tree) + scopename_len);
+		t = talloc_2(sizeof(struct tree) + scopename_len + 1);
 #ifdef _WAVE_HAVE_JUDY
 t_allocated:
 #endif
 		strcpy(t->name, scopename);
 		t->kind = ttype;
 		t->t_which = mtyp;
+		t->t_stem = t_stem;
+		t->t_istem = t_istem;
 
 		if(GLOBALS->mod_tree_parent->child)
 			{
@@ -254,10 +256,12 @@ t_allocated:
 			t = t->next;
 			}
 
-		t = talloc_2(sizeof(struct tree) + scopename_len);
+		t = talloc_2(sizeof(struct tree) + scopename_len + 1);
 		strcpy(t->name, scopename);
 		t->kind = ttype;
 		t->t_which = mtyp;
+		t->t_stem = t_stem;
+		t->t_istem = t_istem;
 
 		t->next = GLOBALS->treeroot;
 		GLOBALS->mod_tree_parent = GLOBALS->treeroot = t;
@@ -265,10 +269,12 @@ t_allocated:
 	}
 	else
 	{
-	t = talloc_2(sizeof(struct tree) + scopename_len);
+	t = talloc_2(sizeof(struct tree) + scopename_len + 1);
 	strcpy(t->name, scopename);
 	t->kind = ttype;
 	t->t_which = mtyp;
+	t->t_stem = t_stem;
+	t->t_istem = t_istem;
 
 	GLOBALS->mod_tree_parent = GLOBALS->treeroot = t;
 	}
@@ -790,7 +796,7 @@ rescan:
 #ifdef _WAVE_HAVE_JUDY
 construct:
 #endif
-		nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
+		nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1 + 1);
 		memcpy(nt->name, GLOBALS->module_tree_c_1, GLOBALS->module_len_tree_c_1);
 
 		if(s)
@@ -830,7 +836,7 @@ construct:
 			{
 			s=get_module_name(s);
 		
-			nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
+			nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1 + 1);
 			memcpy(nt->name, GLOBALS->module_tree_c_1, GLOBALS->module_len_tree_c_1);
 
 			if(s)
@@ -856,7 +862,7 @@ else
 		{
 		s=get_module_name(s);
 
-		nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
+		nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1 + 1);
 		memcpy(nt->name, GLOBALS->module_tree_c_1, GLOBALS->module_len_tree_c_1);
 
 		if(!s) nt->t_which=which; else nt->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
