@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tristan Gingold and Tony Bybell 2006-2012.
+ * Copyright (c) Tristan Gingold and Tony Bybell 2006-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -82,7 +82,6 @@ static void *fix_escaped_names(char *s, int do_free)
 {
 char *s2 = s;
 int found = 0;
-int len;
 
 while(*s2)
 	{
@@ -96,7 +95,6 @@ while(*s2)
 
 if(found)
 	{
-	len = strlen(s);
 	s2 = strdup_2(s);
 	if(do_free) free_2(s);
 	s = s2;
@@ -125,6 +123,7 @@ void
 fill_sig_store (void)
 {
   struct tree *t;
+  struct tree *t_prev = NULL;
   GtkTreeIter iter;
 
   if(GLOBALS->selected_sig_name)
@@ -148,7 +147,20 @@ fill_sig_store (void)
 	unsigned int varxt;
 	char *varxt_pnt;
 
-	if(i < 0) continue;
+	if(i < 0) 
+		{
+		t_prev = NULL;
+		continue;
+		}
+
+	if(t_prev) /* duplicates removal for faulty dumpers */
+		{
+		if(!strcmp(t_prev->name, t->name))
+			{
+			continue;
+			}
+		}
+	t_prev = t;
 
 	varxt = GLOBALS->facs[i]->n->varxt;
 	varxt_pnt = varxt ? varxt_fix(GLOBALS->subvar_pnt[varxt]) : NULL;
@@ -202,10 +214,12 @@ fill_sig_store (void)
                         }
                 }
 
+	wrexm = 0;
 	if 	(
 		(GLOBALS->filter_str_treesearch_gtk2_c_1 == NULL) || 
 		((!GLOBALS->filter_noregex_treesearch_gtk2_c_1) && (wrexm = wave_regex_match(t->name, WAVE_REGEX_TREE)) && (!GLOBALS->filter_matlen_treesearch_gtk2_c_1)) ||
-		(GLOBALS->filter_matlen_treesearch_gtk2_c_1 && (GLOBALS->filter_typ_treesearch_gtk2_c_1 == vardir) && wrexm)
+		(GLOBALS->filter_matlen_treesearch_gtk2_c_1 && (GLOBALS->filter_typ_treesearch_gtk2_c_1 == vardir) && 
+			(wrexm || (wrexm = wave_regex_match(t->name, WAVE_REGEX_TREE)))	)
 		)
       		{
 		gtk_list_store_prepend (GLOBALS->sig_store_treesearch_gtk2_c_1, &iter);
@@ -296,7 +310,7 @@ if(node)
 }
 
 
-int force_open_tree_node(char *name, int keep_path_nodes_open) {
+int force_open_tree_node(char *name, int keep_path_nodes_open, struct tree **t_pnt) {
   GtkCTree *ctree = GLOBALS->ctree_main;
   int rv = 1 ;			/* can possible open */
   if(ctree) {
@@ -315,6 +329,7 @@ int force_open_tree_node(char *name, int keep_path_nodes_open) {
     } 
     for(;;) {
       struct tree *t = gctr->row.data;
+      if(t_pnt) { *t_pnt = t; }
       while(*zap) {
 	if(*zap != GLOBALS->hier_delimeter) {
 	  zap++;
@@ -544,6 +559,7 @@ if(ctree)
 				/* printf("[treeselectnode] '%s' ok\n", name); */
 				gtk_ctree_select(ctree, node);
 
+				GLOBALS->sst_sig_root_treesearch_gtk2_c_1 = t;
 				GLOBALS->sig_root_treesearch_gtk2_c_1 = t->child;
 				fill_sig_store ();
 
@@ -619,6 +635,7 @@ if(node)
 
 t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->ctree_main), row);
 DEBUG(printf("TS: %08x %s\n",t,t->name));
+ GLOBALS->sst_sig_root_treesearch_gtk2_c_1 = t;
  GLOBALS->sig_root_treesearch_gtk2_c_1 = t->child;
  fill_sig_store ();
  gtkwavetcl_setvar(WAVE_TCLCB_TREE_SELECT, GLOBALS->selected_hierarchy_name, WAVE_TCLCB_TREE_SELECT_FLAGS);
@@ -642,6 +659,7 @@ if(t)
 	/* unused */
 	}
 DEBUG(printf("TU: %08x %s\n",t,t->name));
+ GLOBALS->sst_sig_root_treesearch_gtk2_c_1 = NULL;
  GLOBALS->sig_root_treesearch_gtk2_c_1 = GLOBALS->treeroot;
  fill_sig_store ();
 }
@@ -1311,6 +1329,20 @@ if(event->type == GDK_2BUTTON_PRESS)
 return(FALSE);
 }
 
+static gint hier_top_button_press_event_std(GtkWidget *widget, GdkEventButton *event)
+{
+if((event->button == 3) && (event->type == GDK_BUTTON_PRESS))
+        {
+	if(GLOBALS->sst_sig_root_treesearch_gtk2_c_1)
+		{
+	        do_sst_popup_menu (widget, event);
+		return(TRUE);
+		}
+        }
+
+return(FALSE);
+}
+
 /**********************************************************************/
 
 /*
@@ -1372,6 +1404,8 @@ do_tooltips:
     GLOBALS->treesearch_gtk2_window_vbox = vbox = gtk_vbox_new (FALSE, 1);
     gtk_widget_show (vbox);
 
+    gtkwave_signal_connect(GTK_OBJECT(vbox), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL); 
+
     vpan = gtk_vpaned_new ();
     gtk_widget_show (vpan);
     gtk_box_pack_start (GTK_BOX (vbox), vpan, TRUE, TRUE, 1);
@@ -1415,11 +1449,13 @@ do_tooltips:
 
 
     /* Signal names.  */
-    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING);
+    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+    GLOBALS->sst_sig_root_treesearch_gtk2_c_1 = NULL;
     GLOBALS->sig_root_treesearch_gtk2_c_1 = GLOBALS->treeroot;
     fill_sig_store ();
 
     sig_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (GLOBALS->sig_store_treesearch_gtk2_c_1));
+    gtkwave_signal_connect(GTK_OBJECT(sig_view), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL);
 
     /* The view now holds a reference.  We can get rid of our own reference */
     g_object_unref (G_OBJECT (GLOBALS->sig_store_treesearch_gtk2_c_1));
@@ -1648,6 +1684,8 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     vbox = gtk_vbox_new (FALSE, 1);
     gtk_widget_show (vbox);
 
+    gtkwave_signal_connect(GTK_OBJECT(vbox), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL); 
+
     vpan = gtk_vpaned_new (); /* GLOBALS->sst_vpaned is to be used to clone position over during reload */
     GLOBALS->sst_vpaned = (GtkPaned *)vpan;
     if(GLOBALS->vpanedwindow_size_cache)
@@ -1695,10 +1733,12 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 
     /* Signal names.  */
     GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+    GLOBALS->sst_sig_root_treesearch_gtk2_c_1 = NULL;
     GLOBALS->sig_root_treesearch_gtk2_c_1 = GLOBALS->treeroot;
     fill_sig_store ();
 
     sig_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (GLOBALS->sig_store_treesearch_gtk2_c_1));
+    gtkwave_signal_connect(GTK_OBJECT(sig_view), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL);
 
     /* The view now holds a reference.  We can get rid of our own reference */
     g_object_unref (G_OBJECT (GLOBALS->sig_store_treesearch_gtk2_c_1));
@@ -1882,7 +1922,6 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     gtk_box_pack_start (GTK_BOX (hbox), button4, TRUE, FALSE, 0);
 
     gtk_container_add (GTK_CONTAINER (frameh), hbox);
-    gtk_widget_show(vbox);
     return vbox;
 }
 
