@@ -1140,7 +1140,7 @@ for(;;)
 				strcpy(s->str, GLOBALS->yytext_vcd_partial_c_2);
 				s->mod_tree_parent = GLOBALS->mod_tree_parent;
 
-				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_partial_c_2, NULL, GLOBALS->yylen_vcd_partial_c_2, 0);
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_partial_c_2, NULL, GLOBALS->yylen_vcd_partial_c_2, 0, 0, 0);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -2478,6 +2478,10 @@ if(t->vector)
 					bts->nodes[i]->harray = NULL;
 					}
 				}
+				else
+				{
+				t->interactive_vector_needs_regeneration = 1;
+				}
 			}
 		}
 
@@ -2651,10 +2655,30 @@ if(GLOBALS->partial_vcd)
 gtkwave_main_iteration();
 }
 
+
+static void vcd_partial_regen_node_expansion(Trptr t)
+{
+if(!t->vector) 
+	{
+	if(t->n.nd && t->n.nd->expansion)
+		{
+		nptr np_ex = ExtractNodeSingleBit(t->n.nd->expansion->parent, t->n.nd->expansion->parentbit);
+
+		DeleteNode(t->n.nd);
+		t->n.nd = np_ex;
+		t->name_full = np_ex->nname;
+		t->name = (GLOBALS->hier_max_level) ? hier_extract(t->name_full, GLOBALS->hier_max_level) : t->name_full;
+		}
+	}
+
+}
+
 void vcd_partial_mark_and_sweep(int mandclear)
 {
 Trptr t;
 
+
+
 /* node */
 t = GLOBALS->traces.first; while(t) { if(!t->vector) regen_trace_mark(t, mandclear); t = t->t_next; }
 t = GLOBALS->traces.buffer; while(t) { if(!t->vector) regen_trace_mark(t, mandclear); t = t->t_next; }
@@ -2662,6 +2686,10 @@ t = GLOBALS->traces.buffer; while(t) { if(!t->vector) regen_trace_mark(t, mandcl
 t = GLOBALS->traces.first; while(t) { if(!t->vector) regen_trace_sweep(t); t = t->t_next; }
 t = GLOBALS->traces.buffer; while(t) { if(!t->vector) regen_trace_sweep(t); t = t->t_next; }
 
+/* node that is single bit extracted */
+t = GLOBALS->traces.first; while(t) { vcd_partial_regen_node_expansion(t); t = t->t_next; }
+t = GLOBALS->traces.buffer; while(t) { vcd_partial_regen_node_expansion(t); t = t->t_next; }
+
 /* vector */
 t = GLOBALS->traces.first; while(t) { if(t->vector) regen_trace_mark(t, mandclear); t = t->t_next; }
 t = GLOBALS->traces.buffer; while(t) { if(t->vector) regen_trace_mark(t, mandclear); t = t->t_next; }
