@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2012.
+ * Copyright (c) Tony Bybell 1999-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1530,7 +1530,7 @@ for(;;)
 				strcpy(s->str, GLOBALS->yytext_vcd_recoder_c_3);
 				s->mod_tree_parent = GLOBALS->mod_tree_parent;
 
-				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_recoder_c_3, NULL, GLOBALS->yylen_vcd_recoder_c_3, 0);
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_recoder_c_3, NULL, GLOBALS->yylen_vcd_recoder_c_3, 0, 0, 0);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -2796,7 +2796,7 @@ if(suffix_check(fname, ".gz") || suffix_check(fname, ".zip"))
 			if(!GLOBALS->vlist_prepack)
 				{
 				fprintf(stderr, "Warning! File size is %d MB.  This might fail in recoding.\n"
-					"Consider converting it to the fst database format instead.  (See the\n"
+					"Consider converting it to the FST database format instead.  (See the\n"
 					"vcd2fst(1) manpage for more information.)\n"
 					"To disable this warning, set rc variable vcd_warning_filesize to zero.\n"
 					"Alternatively, use the -o, --optimize command line option to convert to FST\n"
@@ -2823,6 +2823,7 @@ if(!GLOBALS->vcd_handle_vcd_recoder_c_2)
 	{
 	fprintf(stderr, "Error opening %s .vcd file '%s'.\n",
 		GLOBALS->vcd_is_compressed_vcd_recoder_c_2?"compressed":"", fname);
+	perror("Why");
 	vcd_exit(255);
 	}
 
