@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2005-2011.
+ * Copyright (c) Tony Bybell 2005-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -49,7 +49,7 @@ if(!strict)
 	{
 	if(ch < AN_COUNT)
 		{
-		return(AN_USTR[ch]);
+		return(AN_STR[ch]);
 		}
 		else
 		{
@@ -60,7 +60,7 @@ else
 	{
 	if(ch < AN_COUNT)
 		{
-		return(AN_USTR4ST[ch]);
+		return(AN_STR4ST[ch]);
 		}
 		else
 		{
@@ -73,15 +73,15 @@ else
 /*
  * generate a vcd identifier for a given facindx
  */
-static char *vcdid(int value, int export_typ)
+static char *vcdid(unsigned int value, int export_typ)
 {
 char *pnt = GLOBALS->buf_vcd_saver_c_3;
-int i, vmod;
+unsigned int vmod;
 
 if(export_typ != WAVE_EXPORT_TRANS)
 	{
 	value++;
-	for(i=0;;i++)
+	for(;;)
 	        {
 	        if((vmod = (value % 94)))
 	                {
