@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2006-9.
+ * Copyright (c) Tony Bybell 2006-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -242,12 +242,12 @@ if(v->siz > 32)
 	{
 	struct vlist_t *vz;
 	unsigned int *ipnt;
-	char *dmem = malloc_2(v->siz);
+	char *dmem = malloc_2(compressBound(v->siz));
 	unsigned long destlen = v->siz;
 	int rc;
 	
 	rc = compress2((unsigned char *)dmem, &destlen, (unsigned char *)(v+1), v->siz, GLOBALS->vlist_compression_depth);
-	if((rc == Z_OK)&&(destlen < (v->siz - sizeof(long))))
+	if( (rc == Z_OK) && ((destlen + sizeof(int)) < v->siz) )
 		{
 		/* printf("siz: %d, dest: %d rc: %d\n", v->siz, (int)destlen, rc); */
 
@@ -516,7 +516,7 @@ if((vl->elem_siz == 1)&&(siz))
 	{
 	struct vlist_t *w, *v2;
 
-	if(vl->offs*2 < vl->siz)
+	if(vl->offs*2 <= vl->siz) /* Electric Fence, change < to <= */
 		{
 		v2 = calloc_2(1, sizeof(struct vlist_t) + (vl->siz /* * vl->elem_siz */)); /* scan-build */
 		memcpy(v2, vl, sizeof(struct vlist_t) + (vl->siz/2 /* * vl->elem_siz */)); /* scan-build */
